# How to customize

<p class="description">Вы можете легко настроить внешний вид компонента Material-UI.</p>

As components can be used in different contexts, there are several approaches to customizing them. Переходя от самого нераспространённого варианта к самому широко используемому, это:

1. [One-off customization](#1-one-off-customization)
1. [Reusable style overrides](#2-reusable-style-overrides)
1. [Dynamic variation](#3-dynamic-variation)
1. [Глобальное изменение темы](#4-global-theme-variation)
1. [Глобальное переопределение CSS](#5-global-css-override)

## 1. One-off customization

Возможно, вам придется изменить стиль компонента в конкретном месте. Для этого вам предоставляются следующие методы:

### Use the `sx` prop

The easiest way to add style overrides for a one-off situation is to use the `sx` prop available on all Material-UI components. Here is an example:

{{"demo": "pages/customization/how-to-customize/SxProp.js"}}

Next you'll see how you can you can use global class selectors for accessing slots inside the component. You'll also learn how to easily identify the classes which are available to you for each of the states and slots in the component.

### Overriding nested component styles

You can use the browser dev tools to identify the slot for the component you want to override. It can save you a lot of time. The styles injected into the DOM by Material-UI rely on class names that [follow a simple pattern](/styles/advanced/#class-names): `[hash]-Mui[Component name]-[name of the slot]`.

⚠️ These class names can't be used as CSS selectors because they are unstable, however, Material-UI applies global class names using a consistent convention: `Mui[Component name]-[name of the slot]`.

Вернемся к упомянутому выше примеру. How can you override the slider's thumb?

<img src="/static/images/customization/dev-tools.png" alt="Инструменты разработчика" width="406" />

In this example, the styles are applied with `.css-ae2u5c-MuiSlider-thumb` so the name of the component is `Slider` and the name of the slot is `thumb`.

You now know that you need to target the `.MuiSlider-thumb` class name for overriding the look of the thumb:

{{"demo": "pages/customization/how-to-customize/DevTools.js"}}

### Переопределение стилей через имена классов

If you would like to override the styles of the components using classes, you can use the `className` prop available on each component. For overriding the styles of the different parts inside the component, you can use the global classes available for each slot, as described in the previous section.

You can find examples of this using different styles libraries in the [Styles library interoperability](/guides/interoperability/) guide.

### Pseudo-classes

Особые состояния компонент, такие как * наведение (hover)*, * фокус *, *disabled* и *selected*, стилизованы при помощи CSS с более высокой специфичностью. [Специфичность - это весовой коэффициент](https://developer.mozilla.org/en-US/docs/Web/CSS/Specificity) применяемый к данной декларации CSS.

Чтобы переопределить особые состояния компонентов, **вам нужно увеличить специфичность**. Вот пример с *disable* состоянием и компонентом кнопка использующим **псевдокласс** (`:disabled`):

```css
.Button {
  color: black;
}

/* Increase the specificity */
.Button:disabled {
  color: white;
}
```

```jsx
<Button disabled className="Button">
```

Sometimes, you can't use a **pseudo-class**, as the state doesn't exist in the web specification. В качестве примера можно привести компонент пункт меню и состояние *выбрано*. You can use the `.Mui-selected` global class name to customize the special state of the `MenuItem` component:

```css
.MenuItem {
  color: black;
}

/* Increase the specificity */
.MenuItem.Mui-selected {
  color: blue;
}
```

```jsx
<MenuItem selected className="MenuItem">
```

#### Почему я должен повышать специфичность для переопределения отдельного состояния компонента?

Спецификация CSS, по определению, обязывает псевдоклассы повышать специфичность. Спецификация CSS, по определению, обязывает псевдоклассы повышать специфичность. Это имеет одно важное преимущество: оно позволяет выбрать определённое состояние, которое вы хотите изменить.

#### What custom pseudo-classes are available in Material-UI?

You can rely on the following [global class names](/styles/advanced/#with-material-ui-core) generated by Material-UI:

| State         | Global class name   |
|:------------- |:------------------- |
| active        | `.Mui-active`       |
| checked       | `.Mui-checked`      |
| disabled      | `.Mui-disabled`     |
| error         | `.Mui-error`        |
| focused       | `.Mui-focused`      |
| focus visible | `.Mui-focusVisible` |
| required      | `.Mui-required`     |
| expanded      | `.Mui-expanded`     |
| selected      | `.Mui-selected`     |

> ⚠️ Never style these pseudo-class class names directly:

```css
/* ❌ NOT OK, impact all the components with unclear side-effects */
.Mui-error {
  color: red;
}

/* ✅ OK */
.MuiOutinedInput-root.Mui-error {
  color: red;
}
```

## 2. Reusable style overrides

If you find that you need the same overrides in multiple places across your application, you can use the `styled()` utility for creating a reusable component:

{{"demo": "pages/customization/how-to-customize/StyledCustomization.js", "defaultCodeOpen": true}}

With it, you have access to all of a component's props to dynamically style the component.

## 3. Dynamic variation

In the previous section, we learned how to override the style of a Material-UI component. Теперь давайте посмотрим, как мы можем сделать эти переопределения динамическими. Here are four alternatives; each has its pros and cons.

### Динамический CSS

{{"demo": "pages/customization/how-to-customize/DynamicCSS.js", "defaultCodeOpen": false}}

### Ответвление имени класса

{{"demo": "pages/customization/how-to-customize/DynamicClassName.js"}}

### CSS переменные

{{"demo": "pages/customization/how-to-customize/DynamicCSSVariables.js"}}

### Вложенные темы

{{"demo": "pages/customization/how-to-customize/DynamicThemeNesting.js"}}

## 4. Глобальное изменение темы

In order to promote consistency between components, and manage the user interface appearance as a whole, Material-UI provides a mechanism to apply global changes.

Please take a look at the theme's [global overrides page](/customization/theme-components/) for more details.

## 5. Глобальное переопределение CSS

Components expose [global class names](/styles/advanced/#with-material-ui-core) to enable customization with CSS.

```css
.MuiButton-root {
  fontsize: '1rem';
}
```

You can reference the [Styles library interoperability guide](/guides/interoperability/) to find examples of this using different styles libraries or plain CSS.

If you just want to add some global baseline styles for some of the HTML elements, you can use the `GlobalStyles` component. Here is an example of how you can override styles for the `h1` elements.

{{"demo": "pages/customization/how-to-customize/GlobalCssOverride.js", "iframe": true, "height": 100}}

If you are already using the [CssBaseline](/components/css-baseline/) component for setting baseline styles, you can also add these global styles as overrides for this component. Here is how you can achieve the same by using this approach.

{{"demo": "pages/customization/how-to-customize/OverrideCssBaseline.js", "iframe": true, "height": 100}}
